#
# spec file for package awesome
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           awesome
Version:        4.3
Release:        5.4
Summary:        Configurable tiling and floating Window Manager
License:        GPL-2.0-or-later
Group:          System/GUI/Other
URL:            https://awesomewm.org/
Source:         https://github.com/awesomeWM/awesome-releases/raw/master/%{name}-%{version}.tar.xz
Source1:        https://github.com/awesomeWM/awesome-releases/raw/master/%{name}-%{version}.tar.xz.asc
Source2:        %{name}.keyring
Patch0:         001-extern-vars-declaration-fix-gcc10.patch
BuildRequires:  ImageMagick
BuildRequires:  cmake
BuildRequires:  doxygen
BuildRequires:  gcc-c++
BuildRequires:  grep
BuildRequires:  lua-lgi >= 0.8.0
BuildRequires:  pkgconfig
BuildRequires:  xmlto
BuildRequires:  Lua(devel) >= 5.2
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(cairo-xcb)
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(gdk-pixbuf-2.0)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(libstartup-notification-1.0) >= 0.10
BuildRequires:  pkgconfig(libxdg-basedir) >= 1.0.0
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xcb-cursor)
BuildRequires:  pkgconfig(xcb-icccm) >= 0.3.8
BuildRequires:  pkgconfig(xcb-keysyms) >= 0.3.4
BuildRequires:  pkgconfig(xcb-randr)
BuildRequires:  pkgconfig(xcb-shape)
BuildRequires:  pkgconfig(xcb-util) >= 0.3.8
BuildRequires:  pkgconfig(xcb-xinerama)
BuildRequires:  pkgconfig(xcb-xkb)
BuildRequires:  pkgconfig(xcb-xrm)
BuildRequires:  pkgconfig(xcb-xtest)
BuildRequires:  pkgconfig(xkbcommon)
BuildRequires:  pkgconfig(xkbcommon-x11)
BuildRequires:  pkgconfig(xproto) >= 7.0.15
BuildRequires:  rubygem(%{rb_default_ruby_abi}:asciidoctor)
BuildRequires:  typelib(GLib)
BuildRequires:  typelib(Gio)
BuildRequires:  typelib(Pango)
BuildRequires:  typelib(PangoCairo)
BuildRequires:  typelib(cairo)
Requires:       %{name}-branding = %{version}
Requires:       lua-lgi
Requires:       typelib(GLib)
Requires:       typelib(Gio)
Requires:       typelib(Pango)
Requires:       typelib(PangoCairo)
Requires:       typelib(cairo)
Provides:       windowmanager
Requires(post): update-alternatives
Requires(postun):update-alternatives

%description
awesome is a dynamic window manager.

It manages windows in several layout modes: tiled, floating, etc.
Each layout can be applied dynamically, optimizing the environment
for the application in use and the task performed.

%package branding-upstream
Summary:        Upstream Branding for awesome
Group:          System/GUI/Other
Requires:       %{name} = %{version}
Supplements:    (%{name} and branding-upstream)
Conflicts:      %{name}-branding
Provides:       %{name}-branding = %{version}
BuildArch:      noarch

%description branding-upstream
This package provides the upstream look and feel for awesome.

%prep
%setup -q
sed -i 's/nano/vi/g' %{name}rc.lua
sed -i 's/^\(Type=\).*$/\1XSession/' %{name}.desktop
sed -i 's/#!\/usr\/bin\/env bash/#!\/bin\/bash/' ./utils/awesome-client
%if 0%{?suse_version} >= 1500
%patch -P 0 -p1
%endif

%build
%cmake \
  -DAWESOME_DOC_PATH=%{_docdir}/%{name} \
  -DXDG_CONFIG_DIR=%{_sysconfdir}/xdg   \
  -DCOMPRESS_MANPAGES=OFF
make %{?_smp_mflags} V=1

%install
%cmake_install

# xsession default selector
mkdir -p %{buildroot}%{_sysconfdir}/alternatives
touch %{buildroot}%{_sysconfdir}/alternatives/default-xsession.desktop
ln -s %{_sysconfdir}/alternatives/default-xsession.desktop %{buildroot}%{_datadir}/xsessions/default.desktop

rm %{buildroot}%{_docdir}/%{name}/LICENSE

%post
%{_sbindir}/update-alternatives --install %{_datadir}/xsessions/default.desktop \
  default-xsession.desktop %{_datadir}/xsessions/awesome.desktop 20

%postun
[ -f %{_datadir}/xsessions/awesome.desktop ] || %{_sbindir}/update-alternatives \
  --remove default-xsession.desktop %{_datadir}/xsessions/awesome.desktop

%files
%license LICENSE
%doc README.md
%doc %{_docdir}/%{name}/
%dir %{_sysconfdir}/xdg/%{name}/
%{_bindir}/%{name}*
%{_datadir}/%{name}/
%exclude %{_datadir}/%{name}/themes/
%{_datadir}/xsessions/default.desktop
%{_datadir}/xsessions/%{name}.desktop
%ghost %{_sysconfdir}/alternatives/default-xsession.desktop
%{_mandir}/man?/%{name}*.?%{?ext_man}
%{_mandir}/*/man?/%{name}*.?%{?ext_man}
%ghost %{_sysconfdir}/alternatives/default.desktop

%files branding-upstream
%license LICENSE
%config(noreplace) %{_sysconfdir}/xdg/%{name}/rc.lua
%{_datadir}/%{name}/themes/

%changelog
* Tue Feb 20 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Wed Dec  8 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update awesome-branding-upstream metadata:
  + do not use otherproviders() conflicts: the syntax is
    deprecated.
  + UUse booleandeps for supplements instead of packageand().
- Add requires(post|postun): upate-alternatives. The scriplets call
  u-a unconditionally, thus we need to ensure presence of
  update-alternatives.
- Properly %%ghost-own /etc/alternatives/default.desktop.
- Drop duplicate LICENSE in docdir: we have it in licensedir.
* Sat Jul 18 2020 Brice DEKANY <brice.dekany@suse.com>
- Added 001-extern-vars-declaration-fix-gcc10.patch: Move variable
  declarations from header to C file to fix build with GCC 10
  See https://github.com/awesomeWM/awesome/pull/3065
* Sat Feb  9 2019 Stephan Kulow <coolo@suse.com>
- Do not hardcode default ruby, but use macro
- package LICENSE as %%license
* Mon Jan 28 2019 mvetter@suse.com
- Update to 4.3 :
  See https://awesomewm.org/apidoc/documentation/89-NEWS.md.html#v43
- Remove awesome-asciidoc-fix.patch:
  asciidoctor is used instead of asciidoc now
* Tue Apr 17 2018 jengelh@inai.de
- Ensure neutrality of descriptions.
* Wed Feb 28 2018 tiwai@suse.de
- Fix the documentation build with asciidoctor (bsc#1075764):
  awesome-asciidoc-fix.patch
* Thu Oct  5 2017 mimi.vx@gmail.com
- relax lua requires for openSUSE:Leap
* Thu Aug  3 2017 sor.alexei@meowr.ru
- Update to version 4.2:
  * See https://awesomewm.org/apidoc/documentation/89-NEWS.md.html#v42
* Mon Jul 24 2017 dimstar@opensuse.org
- Use update-alternatives to create default.desktop xsession (boo#1030873)
* Sun Mar 19 2017 sor.alexei@meowr.ru
- Update to version 4.1:
  * See https://awesomewm.org/apidoc/documentation/89-NEWS.md.html#v41
- Use tarball signing.
* Wed Mar  8 2017 sfalken@opensuse.org
- Edited %%files section to clear unpackaged files builderror
  in openSUSE:Factory
* Mon Jan 16 2017 dheidler@suse.com
- Build again with dbus support (boo#1020112).
* Mon Dec 26 2016 sor.alexei@meowr.ru
- Update to version 4.0:
  * See https://awesomewm.org/changelogs/short/v4.0
- Remove awesome-remove_build_timestamp.patch: fixed upstream.
- Require branding of the same version.
* Thu Nov 17 2016 dimstar@opensuse.org
- Add windowmanager provides (boo#981663).
* Tue Mar 22 2016 kmroz@suse.com
- Update to 3.5.9:
  - Always send ConfigureNotifies
  - Don't modify WM_HINTS in client_set_urgent()
  - Fix awful.ewmh to handle window gravities
  - Check that the Lua stack is empty in the main loop
  - Fix unbalance Lua stack usage in event_handle_leavenotify()
  - Balance the stack in luaA_loadrc()
  - Fix arguments to luaL_checkstack()
  - Make client key bindings for e.g. xeyes work again
  - Change codename
* Sat Jan 30 2016 sor.alexei@meowr.ru
- Update to 3.5.8:
  * Fix window key grabbing.
  * menubar: handle nil Name in .desktop files.
* Sat Jan 16 2016 sor.alexei@meowr.ru
- Update to 3.5.7:
  * tag.lua: add "property::icon_only" signal.
  * Make stdout/stderr line buffered.
  * cmake: s/ESCAPE_QUOTE/ESCAPE_QUOTES/.
  * awesome_atexit: keep client order always.
  * Add .travis.yml from master, ignoring functional tests.
  * awesomeConfig.cmake: Allow setting AWESOME_DATA_DIR.
  * Fix the definition of A_STRNEQ_CASE.
  * Fix focus handling with multiple awesome instances.
  * Remove titlebars from clients during shutdown.
  * a_dbus_message_iter: Handle DBUS_TYPE_DOUBLE.
  * Ignore more events while minimising a client.
  * Screen __index: Don't turn argument into a string.
  * Keep stacking order across restarts.
  * Keep client order across restarts.
  * Force systray redraw on BG colour change.
  * Fix enter/leave events on titlebars.
  * Fix compilation.
  * Handle enter/leave events with detail=Inferior correctly.
  * Never explicitly focus the root window.
  * Fix client_apply_size_hints().
  * Make awesome.quit() during startup work.
  * Fix obvious typo in xwindow_translate_for_gravity().
  * Apply window gravity when a window moves.
  * Refactor code a little.
  * Apply window gravity for titlebar resizes.
  * Apply window gravity for border width changes.
  * Grab client keys on the client window.
  * Spawn: Improve handling of startup notification.
  * objects: Add .valid property.
  * Change codename.
  * awful.menu: update t new layout api.
- Require 3.5+ version of awesome-branding.
* Thu Oct  8 2015 sor.alexei@meowr.ru
- Do not require an explicit awesome-branding version (boo#949464).
* Wed Apr 29 2015 sor.alexei@meowr.ru
- Update to 3.5.6 (changes since 3.4.15):
  * For detailed changelog see:
    http://awesome.naquadah.org/changelogs/short/v3.5
    http://awesome.naquadah.org/changelogs/short/v3.5.1
    http://awesome.naquadah.org/changelogs/short/v3.5.2
    http://awesome.naquadah.org/changelogs/short/v3.5.3
    http://awesome.naquadah.org/changelogs/short/v3.5.4
    http://awesome.naquadah.org/changelogs/short/v3.5.5
    http://awesome.naquadah.org/changelogs/short/v3.5.6
- Remove fix-awesome-desktop-launcher.patch: replaced by a regexp.
- Spec cleanup.
* Wed Aug 13 2014 toganm@opensuse.org
- Allow gdm (and possibly other display managers) to show
  'awesome' in the list of available xsessions
  * Add fix-awesome-desktop-launcher.patch (freyes@suse.com)
* Fri Jan  3 2014 crrodriguez@opensuse.org
- extend awesome-remove_build_timestamp.patch to avoid
  needless package republish due to AWESOME_COMPILE_HOSTNAME
  changing all the time. replace it by the string "OBS".
* Tue Feb 12 2013 toganm@opensuse.org
- Update to 3.4.15
  * Fix keyboard layouts
- Changes between 3.4.13 and 3.4.14
  * Add NoDisplay to .desktop file (FS#1031)
  * Remove incorrect comment.
  * Have only FreeBSD require dynamic linking (FS#743)
  * Add x11-xcb to the pkg-config checks
  * naughty: Correctly handle rowstride on icons
  * Fix client screen in awful.client.setslave
  * Added initial support for Xlib cursor themes
- Use xz format for the source files
- Added xcursor to BuildRequires
* Thu Dec  6 2012 toganm@opensuse.org
- Created subpackage awesome-branding-upstream which includes the
  the default themes of the awesome package
* Wed Nov  7 2012 cfarrell@suse.com
- license update: GPL-2.0+
  No indication that the package limits licensing to only version 2 of the
  GPL
* Mon Nov  5 2012 toganm@opensuse.org
- rathen then the hack use awesome-remove_timestamp_from_build by
  pascal.bleser@opensuse.org to get rid of build time in builds
  causing unnecessary builds
* Mon Sep 24 2012 toganm@opensuse.org
- switch back to lua51-devel instead of pkgconfig
* Thu Sep 13 2012 toganm@opensuse.org
- correct missing man locale dirs
* Sun Aug 19 2012 toganm@opensuse.org
- Use vi as the default editor
* Mon Aug 13 2012 toganm@opensuse.org
- Update to 3.4.13
  - Remove PREFIX, use CMAKE_INSTALL_PREFIX
  - Simplify client focus code
  - change codename
  - awful.titlebar use height not width
  - xerror: Print numeric infos about the error
  - Revert "Focus history: Don't ignore unfocusable clients"
* Fri Jul  6 2012 toganm@opensuse.org
- use pkgconfig for available buildrequires
* Fri Jun 15 2012 toganm@opensuse.org
- Update to 3.4.12 for changes see
  http://awesome.naquadah.org/changelogs/v3.4.12
  * removed glib-single-include.patch as it is fixed upstream
* Tue Apr 17 2012 toganm@opensuse.org
- update to 3.4.11
  see  http://awesome.naquadah.org/changelogs/v3.4.10
  * removed confuse related patch
  * fix Factory builds with glib-single-include.patch
* Fri Jul 29 2011 chris@computersalat.de
- update to 3.4.10
  see http://awesome.naquadah.org/changelogs/v3.4.10
- rebase openSUSE_them patch
- spec-cleaner
- fix deps
  o add cairo-devel (for xcb backend, experimental)
* Mon Jan 17 2011 pascal.bleser@opensuse.org
- update to 3.4.9
* Tue Jun  1 2010 adam@mizerski.pl
- added Requires: imlib2-loaders
* Wed May 12 2010 pascal.bleser@opensuse.org
- update to 3.4.5
* Sat Dec 13 2008 guru@unixtech.be
- update to 3.1
* Sun Aug 31 2008 guru@unixtech.be
- update to 2.3.4
- use in-tree libconfuse (statically linked)
* Sat Aug  2 2008 guru@unixtech.be
- moved to X11:windowmanagers/
- upgrade to 2.3.3
* Wed Jan  2 2008 mrueckert@suse.de
- update to version 2.0
* Sat Oct  6 2007 mrueckert@suse.de
- fixed build on older distributions
* Tue Sep 25 2007 mrueckert@suse.de
- update to version 1.1
* Wed Sep 19 2007 mrueckert@suse.de
- initial package
